@@ -64,7 +64,7 @@ def validate_options(parser, options):
 
     if options.max_length < options.min_length:
         sys.stderr.write("The maximum length of a word can not be "
-                         "lesser then minimum length.\n"
+                         "less than the minimum length.\n"
                          "Check the specified settings.\n")
         sys.exit(1)
 
@@ -104,6 +104,9 @@ def generate_wordlist(wordfile=None,
     Generate a word list from either a kwarg wordfile, or a system default
     valid_chars is a regular expression match condition (default - all chars)
     """
+                      
+    if wordfile is None:
+        wordfile = locate_wordfile()
 
     words = []
 
